@@ -181,7 +181,7 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         The (total, homogeneous) *degree*, the maximal sum of the
         monomial degrees of monomials with nonzero coefficients. 
-        Returns -1 for the zero polynomial.
+        Returns :math:`-1` for the zero polynomial.
         """
         nzis = np.nonzero(self.coef)
         degs = [sum(t) for t in zip(*nzis)]
