@@ -197,7 +197,7 @@ class MVPolyDict(mvpoly.base.MVPoly) :
         """
         The (total, homogeneous) *degree*, the maximal sum of the
         monomial degrees of monomials with nonzero coefficients. 
-        Returns -1 for the zero polynomial.
+        Returns :math:`-1` for the zero polynomial.
         """
         degs = [np.sum(MVPolyDictMonomial(key = k).dict.values())
                 for k in self.coef.keys()]
