@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # tests which are applied to all sublcasses -- these do not
 # use the internal representation of the subclass
 
@@ -419,6 +420,41 @@ class TestMVPolyCompose(unittest.TestCase) :
             q = p.compose(y, x)
             self.assertTrue(q(1, 0) == 1, "bad compose")
 
+    def test_compose_diff_nvar(self) :
+        # one should be able to convert a 1-d polynomial in one
+        # variable to a 1-d polynomial in another; compose() should
+        # do this and we test that this is case ...
+        for C in classes :
+            x, y = C.monomials(2, dtype=int)        
+            px = C.lehmer()
+            py = px(y)
+            self.assertTrue(px.degrees == (10,), "bad nvar compose")
+            self.assertTrue(py.degrees == (0,10), "bad nvar compose")
+
+
+class TestMVPolyDiv(unittest.TestCase) :
+
+    def test_div_scalar(self) :
+        for C in classes :
+            x, y = C.monomials(2, dtype=int)
+            p1 = (2*x + 6*y)/2
+            p2 = (3*x + 7*y)/2
+            q = x + 3*y
+            self.assertTrue(p1 == q, "div scalar 1")
+            self.assertTrue(p2 == q, "div scalar 2")
+
+    def test_div_poly_raises_typerror(self) :
+        # Division of polynomials is not supported in this
+        # library, since in the multivariate case it involves
+        # Gröbner basis calculation (which is unstable for 
+        # floating-point coefficients). There is research on
+        # stabilised (regularised) Gröbner bases but adding
+        # that work to this library would be a major project.
+        for C in classes :
+            x, y = C.monomials(2, dtype=int)
+            self.assertRaises(TypeError, x.__div__, y)
+            self.assertRaises(TypeError, x.__div__, x)
+
 
 class TestMVPolyDiff(unittest.TestCase) :
 
@@ -621,6 +657,10 @@ class TestMVPolyMaxmodND(unittest.TestCase) :
         # N. Varopoulos, On an inequality of von Neumann and an 
         # application of themetric theory of tensor products to 
         # operator theory, J. Funct. Anal., 16 (1974), 83--100.
+        #
+        # Note that the maximum modulus here is attained on a 
+        # continuum on the ball: a large eps is needed to halt
+        # the algorithm before exponential blowup
         eps = 1e-5
         for C in classes :
             x, y, z = C.monomials(3, dtype=complex)
@@ -675,7 +715,7 @@ class TestMVPolyRudinShapiro(unittest.TestCase) :
 
     def test_rudin_shapiro_maxmod(self) :
         # this inequality is what makes these polynomials interesting,
-        # they have rather small maximum modulu
+        # they have rather small maximum modulus
         for C in classes :
             eps = 1e-10
             for m in range(2,7) :
@@ -684,13 +724,13 @@ class TestMVPolyRudinShapiro(unittest.TestCase) :
                 self.assertTrue(M*(1-eps) < np.sqrt(2**(m+1)), 
                                 "rudin-shapiro maxmod")
 
+    @unittest.skip("pending implementation of norm_L(p)")
     def test_rudin_shapiro_L4_norm(self) :
         # for norm tests : Littlewood, if n = 2^k - 1, P the Rudin-Shapiro
         # polynomial order n, then 
         #
         #       ||P||_L4^4  =  (1/3)((4n+1)^2 - (-1)^k (n+1))
         # 
-        # to be done when norm_L(p) is implemented
         pass
 
 class TestMVPolyLehmer(unittest.TestCase) :
@@ -698,20 +738,20 @@ class TestMVPolyLehmer(unittest.TestCase) :
     def test_lehmer_size(self) :
         for C in classes :
             p = C.lehmer(dtype=int)
-            self.assertTrue(p.degrees == (10,), "rudin-shapiro degrees")
+            self.assertTrue(p.degrees == (10,), "lehmer degrees")
 
     def test_lehmer_dtype(self) :
         for C in classes :
             for dt in [int, float, np.double] :
                 p = C.lehmer(dtype=dt)
-                self.assertTrue(p.dtype == dt, "rudin-shapiro dtype")
+                self.assertTrue(p.dtype == dt, "lehmer dtype")
 
     def test_lehmer_explicit(self) :
         for C in classes :
             p = C.lehmer(dtype=int)
             x, = C.monomials(1, dtype=int)
             q = x**10 + x**9 - x**7 - x**6 - x**5 - x**4 - x**3 + x + 1
-            self.assertTrue(p == q, "rudin-shapiro explicit")
+            self.assertTrue(p == q, "lehmer explicit")
             
 
 class TestMVPolyBernstein(unittest.TestCase) :
@@ -737,12 +777,12 @@ class TestMVPolyBernstein(unittest.TestCase) :
         for C in classes :
             for dt in [int, float, np.double] :
                 p = C.bernstein((3,2), (5,7), dtype=dt)
-                self.assertTrue(p.dtype == dt, "rudin-shapiro dtype")
+                self.assertTrue(p.dtype == dt, "bernstein dtype")
 
 class TestMVPolySpecial(unittest.TestCase) :
 
     # we test a selection of the scipy.special polys, checking
-    # that they agree with the classical defunition
+    # that they agree with the classical definition
 
     def test_legendre_size(self) :
         for C in classes :
